aboutsummaryrefslogtreecommitdiff
path: root/gcc/ada
diff options
context:
space:
mode:
authorNathan Sidwell <nathan@codesourcery.com>2003-05-01 18:44:48 +0000
committerNathan Sidwell <nathan@gcc.gnu.org>2003-05-01 18:44:48 +0000
commit561712fe49d3fd56e1accd12eb9dc51361a92e3d (patch)
tree20500230da31f2d83474fec30a985aa350e78098 /gcc/ada
parente1a4211d228816f0e0178ffc9f807b72e9dea26c (diff)
downloadgcc-561712fe49d3fd56e1accd12eb9dc51361a92e3d.zip
gcc-561712fe49d3fd56e1accd12eb9dc51361a92e3d.tar.gz
gcc-561712fe49d3fd56e1accd12eb9dc51361a92e3d.tar.bz2
trans.c (tree_transform, [...]): Rename lineno to input_line.
* trans.c (tree_transform, build_unit_elab, set_lineno): Rename lineno to input_line. From-SVN: r66343
Diffstat (limited to 'gcc/ada')
-rw-r--r--gcc/ada/ChangeLog4
-rw-r--r--gcc/ada/trans.c12
2 files changed, 8 insertions, 8 deletions
diff --git a/gcc/ada/ChangeLog b/gcc/ada/ChangeLog
index 3197152..a4afa62 100644
--- a/gcc/ada/ChangeLog
+++ b/gcc/ada/ChangeLog
@@ -1,7 +1,7 @@
2003-05-01 Nathan Sidwell <nathan@codesourcery.com>
- * trans.c (build_unit_elab, set_lineno): Rename lineno to
- input_line.
+ * trans.c (tree_transform, build_unit_elab,
+ set_lineno): Rename lineno to input_line.
* utils.c (pushdecl, create_label_decl, begin_subprog_body,
end_subprog_body): Likewise.
* utils2.c (build_call_raise): Likewise.
diff --git a/gcc/ada/trans.c b/gcc/ada/trans.c
index be5c656..064e543 100644
--- a/gcc/ada/trans.c
+++ b/gcc/ada/trans.c
@@ -2620,7 +2620,7 @@ tree_transform (gnat_node)
correctly. */
set_lineno (gnat_node, 0);
DECL_SOURCE_FILE (gnu_subprog_decl) = input_filename;
- DECL_SOURCE_LINE (gnu_subprog_decl) = lineno;
+ DECL_SOURCE_LINE (gnu_subprog_decl) = input_line;
begin_subprog_body (gnu_subprog_decl);
set_lineno (gnat_node, 1);
@@ -3782,7 +3782,7 @@ tree_transform (gnat_node)
gnu_orig_out_list = nreverse (gnu_orig_out_list);
expand_asm_operands (gnu_template, gnu_output_list, gnu_input_list,
gnu_clobber_list, Is_Asm_Volatile (gnat_node),
- input_filename, lineno);
+ input_filename, input_line);
/* Copy all the intermediate outputs into the specified outputs. */
for (; gnu_output_list;
@@ -5351,7 +5351,7 @@ build_unit_elab (gnat_unit, body_p, gnu_elab_list)
&& TYPE_IS_PADDING_P (TREE_TYPE (lhs)))
lhs = convert (TREE_TYPE (TYPE_FIELDS (TREE_TYPE (lhs))), lhs);
- emit_line_note (input_filename, lineno);
+ emit_line_note (input_filename, input_line);
expand_expr_stmt (build_binary_op (MODIFY_EXPR, NULL_TREE,
TREE_PURPOSE (gnu_elab_list),
TREE_VALUE (gnu_elab_list)));
@@ -5380,9 +5380,9 @@ build_unit_elab (gnat_unit, body_p, gnu_elab_list)
extern char *__gnat_to_canonical_file_spec PARAMS ((char *));
/* Determine the input_filename and the lineno from the source location
(Sloc) of GNAT_NODE node. Set the global variable input_filename and
- lineno. If WRITE_NOTE_P is true, emit a line number note. */
+ input_line. If WRITE_NOTE_P is true, emit a line number note. */
void
set_lineno (gnat_node, write_note_p)
@@ -5417,7 +5417,7 @@ set_lineno (gnat_node, write_note_p)
input_line = Get_Logical_Line_Number (source_location);
if (write_note_p)
- emit_line_note (input_filename, lineno);
+ emit_line_note (input_filename, input_line);
}
/* Post an error message. MSG is the error message, properly annotated.
@@ -5380,9 +5380,9 @@ build_unit_elab (gnat_unit, body_p, gnu_elab_list)
extern char *__gnat_to_canonical_file_spec PARAMS ((char *));
-/* Determine the input_filename and the lineno from the source location
+/* Determine the input_filename and the input_line from the source location
(Sloc) of GNAT_NODE node. Set the global variable input_filename and